@@ -16,20 +16,20 @@ Async do |top|
 	interrupt.install!
 	
 	endpoint.bind do |server, task|
-		Async.logger.info(server) {"Accepting connections on #{server.local_address.inspect}"}
+		Console.logger.info(server) {"Accepting connections on #{server.local_address.inspect}"}
 		
 		task.async do |subtask|
 			interrupt.wait
 			
-			Async.logger.info(server) {"Closing server socket..."}
+			Console.logger.info(server) {"Closing server socket..."}
 			server.close
 			
 			interrupt.default!
 			
-			Async.logger.info(server) {"Waiting for connections to close..."}
+			Console.logger.info(server) {"Waiting for connections to close..."}
 			subtask.sleep(4)
 			
-			Async.logger.info(server) do |buffer|
+			Console.logger.info(server) do |buffer|
 				buffer.puts "Stopping all tasks..."
 				task.print_hierarchy(buffer)
 				buffer.puts "", "Reactor Hierarchy"
@@ -45,11 +45,11 @@ Async do |top|
 			stream = Async::IO::Stream.new(peer)
 			
 			while chunk = stream.read_partial
-				Async.logger.debug(self) {chunk.inspect}
+				Console.logger.debug(self) {chunk.inspect}
 				stream.write(chunk)
 				stream.flush
 				
-				Async.logger.info(server) do |buffer|
+				Console.logger.info(server) do |buffer|
 					task.reactor.print_hierarchy(buffer)
 				end
 			end
