@@ -6,7 +6,9 @@ gemspec
 
 group :maintenance, optional: true do
 	gem "bake-modernize"
-	gem "bake-bundler"
+	gem "bake-gem"
+	
+	gem "utopia-project"
 end
 
 group :test do
