@@ -21,6 +21,7 @@
 # THE SOFTWARE.
 
 require_relative 'endpoint'
+require_relative 'composite_endpoint'
 
 module Async
 	module IO
@@ -29,7 +30,13 @@ module Async
 			# Create a new `SharedEndpoint` by binding to the given endpoint.
 			def self.bound(endpoint, backlog: Socket::SOMAXCONN, close_on_exec: false)
 				wrappers = endpoint.bound do |server|
-					server.listen(backlog)
+					# This is somewhat optional. We want to have a generic interface as much as possible so that users of this interface can just call it without knowing a lot of internal details. Therefore, we ignore errors here if it's because the underlying socket does not support the operation.
+					begin
+						server.listen(backlog)
+					rescue Errno::EOPNOTSUPP
+						# Ignore.
+					end
+					
 					server.close_on_exec = close_on_exec
 					server.reactor = nil
 				end
@@ -57,6 +64,22 @@ module Async
 			attr :endpoint
 			attr :wrappers
 			
+			def local_address_endpoint(**options)
+				endpoints = @wrappers.map do |wrapper|
+					AddressEndpoint.new(wrapper.to_io.local_address)
+				end
+				
+				return CompositeEndpoint.new(endpoints, **options)
+			end
+			
+			def remote_address_endpoint(**options)
+				endpoints = @wrappers.map do |wrapper|
+					AddressEndpoint.new(wrapper.to_io.remote_address)
+				end
+				
+				return CompositeEndpoint.new(endpoints, **options)
+			end
+			
 			# Close all the internal wrappers.
 			def close
 				@wrappers.each(&:close)
