@@ -32,9 +32,9 @@ RSpec.shared_examples_for Async::IO::SharedEndpoint do |container_class|
 	include_context Async::RSpec::SSL::VerifiedContexts
 	include_context Async::RSpec::SSL::ValidCertificate
 	
-	let(:endpoint) {Async::IO::Endpoint.tcp("127.0.0.1", 6781, reuse_port: true)}
-	let(:server_endpoint) {Async::IO::SSLEndpoint.new(endpoint, ssl_context: server_context)}
-	let(:client_endpoint) {Async::IO::SSLEndpoint.new(endpoint, ssl_context: client_context)}
+	let!(:endpoint) {Async::IO::Endpoint.tcp("127.0.0.1", 6781, reuse_port: true)}
+	let!(:server_endpoint) {Async::IO::SSLEndpoint.new(endpoint, ssl_context: server_context)}
+	let!(:client_endpoint) {Async::IO::SSLEndpoint.new(endpoint, ssl_context: client_context)}
 	
 	let!(:bound_endpoint) do
 		Async do
