@@ -26,7 +26,7 @@ RSpec.describe Async::IO::Socket do
 	include_context Async::RSpec::Reactor
 	
 	# Shared port for localhost network tests.
-	let(:server_address) {Async::IO::Address.udp("127.0.0.1", 6778)}
+	let!(:server_address) {Async::IO::Address.udp("127.0.0.1", 6778)}
 	let(:data) {"The quick brown fox jumped over the lazy dog."}
 	
 	let!(:server_task) do
